local AddonName, Addon = ...
local Utils = Addon.Utils

local ApplicantsModule = Addon:CreateModule("Applicants")

function ApplicantsModule:Initialize()
    if not MPR_DB then
        MPR_DB = {}
    end
    
    if MPR_DB.ApplicantsEnabled == nil then
        MPR_DB.ApplicantsEnabled = true
    end
    
    self.enabled = MPR_DB.ApplicantsEnabled

    hooksecurefunc("LFGListApplicationViewer_UpdateResults", function(self)
        if not ApplicantsModule.enabled then return end
        
        local scrollFrame = self.ScrollFrame
        if not scrollFrame or not scrollFrame.buttons then return end
        
        for i, button in ipairs(scrollFrame.buttons) do
            if button and button.Members then
                for j, memberButton in ipairs(button.Members) do
                    if memberButton and not memberButton.hooked then
                        memberButton:HookScript("OnEnter", function(self)
                            local applicantID = button.applicantID
                            if not applicantID then return end
                            
                            local name = select(1, C_LFGList.GetApplicantMemberInfo(applicantID, j))
                            if name then
                                local playerName = name:match("([^-]+)")
                                if playerName then
                                    GameTooltip:SetOwner(self, "ANCHOR_RIGHT")
                                    local playerInfo = Utils:GetPlayerInfo(playerName)
                                    if playerInfo then
                                        Utils:AddMythicPlusInfo(GameTooltip, playerInfo)
                                    end
                                    GameTooltip:Show()
                                end
                            end
                        end)
                        
                        memberButton:HookScript("OnLeave", function()
                            GameTooltip:Hide()
                        end)
                        
                        memberButton.hooked = true
                    end
                end
            end
        end
    end)

    return true
end