local AddonName, Addon = ...
local Utils = Addon.Utils
local L = Addon.L

local LFGModule = Addon:CreateModule("LFG")

function LFGModule:Initialize()
    if not MPR_DB then
        MPR_DB = {}
    end
    
    if MPR_DB.LFGEnabled == nil then
        MPR_DB.LFGEnabled = true
    end

    if MPR_DB.teamEnabled == nil then
        MPR_DB.teamEnabled = false
    end
    
    self.enabled = MPR_DB.LFGEnabled

    self.tooltip = CreateFrame("GameTooltip", "MPlusScoreTooltip", UIParent, "GameTooltipTemplate")
    self.membersTooltip = CreateFrame("GameTooltip", "MembersTooltip", UIParent, "GameTooltipTemplate")

    hooksecurefunc("LFGListUtil_SetSearchEntryTooltip", function(tooltip, resultID) 
        local searchResultInfo = C_LFGList.GetSearchResultInfo(resultID)
        if not searchResultInfo then 
            Addon:PrintDebug("No searchResultInfo")
            return 
        end
    
        local leaderName = searchResultInfo.leaderName
        local numMembers = searchResultInfo.numMembers
        local activityID = searchResultInfo.activityID
        local categoryID = select(3, C_LFGList.GetActivityInfo(activityID))
        local options

        if MPR_DB.teamEnabled then
            local activityID = searchResultInfo.activityID
            local categoryID = select(3, C_LFGList.GetActivityInfo(activityID))

            local members = {}
		    for i=1, numMembers do
		    	local role, class, classLocal = C_LFGList.GetSearchResultMemberInfo(resultID, i)
                table.insert(members, {role = role, class = classLocal})
		    end

            self.membersTooltip:SetOwner(tooltip, "ANCHOR_BOTTOM", 0, -3)

            Utils:AddLFGMembers(self.membersTooltip, members)
            self.membersTooltip:Show()
        end

        if categoryID ~= 2 then return end
        
        Addon:PrintDebug(GetDungeonNameFromSearchResult(searchResultInfo.activityID))

        local playerInfo = Utils:GetPlayerInfo(leaderName)
        Addon:PrintDebug(playerInfo)
        if playerInfo then
            if MPR_DB.teamEnabled then
                self.tooltip:SetOwner(self.membersTooltip, "ANCHOR_BOTTOM", 0, -3)
            else
                self.tooltip:SetOwner(tooltip, "ANCHOR_BOTTOM", 0, -3)
            end
            if IsShiftKeyDown() then 
                options = {
                    short = false,
                }
            else 
                options = {
                    short = MPR_DB.shortTooltip
                }
            end
            Utils:AddMythicPlusInfo(self.tooltip, playerInfo, options)
            self.tooltip:Show()
        end
    end)

    function GetDungeonNameFromSearchResult(activityID)
        if not activityID then
            return "Unknown Dungeon"
        end

        local dungeonNames = {
            [502] = "Атал'Дазар",
            [507] = "Подгнилье",
            [504] = "Храм Сетралисс",
            [510] = "ЗОЛОТАЯ ЖИЛА!!!",
            [514] = "Гробница королей",
            [661] = "Гробница королей",
            [518] = "Вольная Гавань",
            [522] = "Святилище Штормов",
            [526] = "Тол Дагор",
            [530] = "Усадьба Уэйкрестов",
            [534] = "Осада Боралуса",
            [659] = "Осада Боралуса"
        }

        if dungeonNames[activityID] then
            return dungeonNames[activityID]
        end

        return "Unknown Dungeon (" .. tostring(activityID) .. ")"
    end

    
    GameTooltip:HookScript("OnHide", function()
        self.tooltip:Hide()
        self.membersTooltip:Hide()
    end)

    local scrollFrame = LFGListFrame.SearchPanel.ScrollFrame
    if scrollFrame then
        scrollFrame:HookScript("OnVerticalScroll", function()
            self.tooltip:Hide()
            self.membersTooltip:Hide()
        end)
        scrollFrame:HookScript("OnMouseWheel", function()
            self.tooltip:Hide()
            self.membersTooltip:Hide()
        end)
    end

    return true
end