local AddonName, Addon = ...
local Utils = Addon.Utils
local L = Addon.L

local TooltipModule = Addon:CreateModule("Tooltip")

local isElvUI = false
local E
if IsAddOnLoaded("ElvUI") then
    isElvUI = true
    E = unpack(ElvUI)
end

function TooltipModule:Initialize()
    if not MPR_DB then
        MPR_DB = {}
    end
    
    if MPR_DB.tooltipEnabled == nil then
        MPR_DB.tooltipEnabled = true
    end
    
    if MPR_DB.shortTooltip == nil then
        MPR_DB.shortTooltip = false
    end

    self.enabled = MPR_DB.tooltipEnabled
    self.shortTooltip = MPR_DB.shortTooltip

    if isElvUI then
        hooksecurefunc(E:GetModule('Tooltip'), 'GameTooltip_OnTooltipSetUnit', function(self)
            if not TooltipModule.enabled then return end
            TooltipModule:AddPlayerInfo(GameTooltip)
        end)
    else
        GameTooltip:HookScript("OnTooltipSetUnit", function(self)
            if not TooltipModule.enabled then return end
            TooltipModule:AddPlayerInfo(self)
        end)
    end

    local function OnHyperlinkEnter(self, linkData, link)
        if not TooltipModule.enabled then return end
        if not IsShiftKeyDown() then return end

        local linkType, linkContent = linkData:match("^([^:]+):(.+)$")
        if linkType == "player" then
            local playerName = linkContent:match("([^:]+)")
            if playerName then
                GameTooltip:SetOwner(self, "ANCHOR_CURSOR")
                local playerInfo = Utils:GetPlayerInfo(playerName)
                if playerInfo then
                    Utils:AddMythicPlusInfo(GameTooltip, playerInfo)
                end
                GameTooltip:Show()
            end
        end
    end

    local function OnHyperlinkLeave(self, linkData, link)
        GameTooltip:Hide()
    end

    for i = 1, NUM_CHAT_WINDOWS do
        local frame = _G["ChatFrame"..i]
        if frame then
            frame:HookScript("OnHyperlinkEnter", OnHyperlinkEnter)
            frame:HookScript("OnHyperlinkLeave", OnHyperlinkLeave)
        end
    end

    return true
end

function TooltipModule:AddPlayerInfo(tooltip)
    local name, unit = tooltip:GetUnit()
    Addon:PrintDebug(string.format("Name: %s UnitType: %s", name, unit))
    if not unit or not UnitIsPlayer(unit) then return end

    local inArena = IsActiveBattlefieldArena()
    local inBattleground = UnitInBattleground("player")
    local isPvPInstance = select(2, IsInInstance()) == "pvp" or select(2, IsInInstance()) == "arena"
    
    if inArena or inBattleground or isPvPInstance then
        return
    end
    
    local playerName = UnitName(unit)
    local playerInfo = Utils:GetPlayerInfo(playerName)
    if not playerInfo or not playerInfo.data or not playerInfo.data.score then return end
    local options

    if IsShiftKeyDown() then 
        options = {
            short = false,
        }
    else 
        options = {
            short = MPR_DB.shortTooltip
        }
    end

    Utils:AddMythicPlusInfo(tooltip, playerInfo, options)
    tooltip:Show()
end