local AddonName, Addon = ...

function Addon:CreateSettingsManager()
    local SettingsManager = {}

    function SettingsManager:InitializeDB()
        if not MPR_DB then
            MPR_DB = {}
        end

        if MPR_DB.debug == nil then
            MPR_DB.debug = false
        end

        if MPR_DB.teamEnabled == nil then
            MPR_DB.teamEnabled = false
        end
        
        if MPR_DB.hideHeader == nil then
            MPR_DB.hideHeader = false
        end

        if MPR_DB.hideRoles == nil then
            MPR_DB.hideRoles = false
        end

        if MPR_DB.hideRank == nil then
            MPR_DB.hideRank = false
        end

        if MPR_DB.hideILvl == nil then
            MPR_DB.hideILvl = false
        end
        
        if MPR_DB.enableTop1 == nil then
            MPR_DB.enableTop1 = false
        end

        if MPR_DB.shortTooltip == nil then
            MPR_DB.shortTooltip = false
        end

        if MPR_DB.showSeasons == nil then
            MPR_DB.showSeasons = {}
        end

        if type(MPR_DB.showSeasons) ~= "table" then
            MPR_DB.showSeasons = {}
        end

        if MPR_DB.debug then
            Addon:PrintDebug("MPR_DB initialized. showSeasons: " .. (#MPR_DB.showSeasons > 0 and table.concat(MPR_DB.showSeasons, ", ") or "All"))
        end
    end

    function SettingsManager:CreatePanel()
        if self.panel then
            return self.panel
        end

        local panel = CreateFrame("Frame")
        panel.name = L.PANEL_NAME

        local title = panel:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
        title:SetPoint("TOPLEFT", 16, -16)
        title:SetText(L.PANEL_NAME)

        local description = panel:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
        description:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -8)
        description:SetText(L.PANEL_DESCRIPTION .. " " ..L.PANEL_NAME)

        local scrollFrame = CreateFrame("ScrollFrame", nil, panel, "UIPanelScrollFrameTemplate")
        scrollFrame:SetPoint("TOPLEFT", description, "BOTTOMLEFT", 0, 10)
        scrollFrame:SetPoint("BOTTOMRIGHT", panel, "BOTTOMRIGHT", -30, 10)

        local content = CreateFrame("Frame", nil, scrollFrame)
        content:SetSize(scrollFrame:GetWidth() - 5, 1)
        scrollFrame:SetScrollChild(content)

        panel.content = content
        panel.scrollFrame = scrollFrame

        InterfaceOptions_AddCategory(panel)
        self.panel = panel
        return panel
    end

    function SettingsManager:IsSeasonSelected(seasonNumber)
        if not MPR_DB.showSeasons then
            return true
        end
    
        if MPR_DB.showSeasons._empty then
            return false
        end
    
        if #MPR_DB.showSeasons == 0 then
            return true
        end
    
        for _, season in ipairs(MPR_DB.showSeasons) do
            if season == seasonNumber then
                return true
            end
        end
    
        return false
    end
    

    function SettingsManager:Open()
        InterfaceOptionsFrame_OpenToCategory(self.panel)
        InterfaceOptionsFrame_OpenToCategory(self.panel)
        
        if self.UpdateSeasonCheckboxes then
            self:UpdateSeasonCheckboxes()
        end
    end

    function SettingsManager:Initialize()
        self:InitializeDB()
        self:CreatePanel()
    
        self.currentYOffset = 0
    
        self:AddHeader(L.GENERAL_SETTINGS or "General Settings")
    
        self:AddCheckbox(
            L.OPTION_TEAM_ENABLED or "Show Team Info", 
            L.OPTION_TEAM_ENABLED_DESC or "Show information about team members in LFG tool", 
            "teamEnabled", 
            true
        )
    
        self:AddCheckbox(
            L.OPTION_SHORT_TOOLTIP or "Use Short Tooltip", 
            L.OPTION_SHORT_TOOLTIP_DESC or "Display compact tooltip with less information", 
            "shortTooltip", 
            false
        )
    
        self:AddCheckbox(
            L.DEBUG_MODE or "Debug Mode", 
            L.DEBUG_MODE_TOOGLE_DESK or "Enable debug messages", 
            "debug", 
            false
        )
    
        self:AddHeader(L.SEASONS_DISPLAY_OPTIONS or "Seasons Display Options")
    
        local seasonSelector = self:AddSeasonSelector()
        self.UpdateSeasonCheckboxes = seasonSelector.updateCheckboxes
    
        self:AddHeader(L.OTHER_OPTIONS or "Other Options")

        self:AddCheckbox(
            L.HIDE_ROLES or "TEXT_HIDE_ROLES", 
            L.HIDE_ROLES or "TEXT_HIDE_ROLES", 
            "hideRoles", 
            false
        )
    
        self:AddCheckbox(
            L.HIDE_HEADER or "TEXT_HIDE_HEADER", 
            L.HIDE_HEADER or "TEXT_HIDE_HEADER", 
            "hideHeader", 
            false
        )

        self:AddCheckbox(
            L.HIDE_RANK or "TEXT_HIDE_RANK", 
            L.HIDE_RANK or "TEXT_HIDE_RANK", 
            "hideRank", 
            false
        )

        self:AddCheckbox(
            L.HIDE_ILVL or "TEXT_HIDE_ILVL", 
            L.HIDE_ILVL or "TEXT_HIDE_ILVL", 
            "hideILvl", 
            false
        )

        self:AddCheckbox(
            L.enableTop1 or "TEXT_enableTop1", 
            L.enableTop1 or "TEXT_enableTop1", 
            "enableTop1", 
            false
        )

        self:AddTestTooltip()
    
        local content = self.panel.content
        content:SetHeight(math.abs(self.currentYOffset) + 100)
    
        Addon:RegisterCommand("config", function()
            self:Open()
        end, L.COMMAND_CONFIG_DESC or "Open configuration panel")
    end
    
    function SettingsManager:AddTestTooltip()
        local panel = self:CreatePanel()
        local content = panel.content
    
        self:AddHeader(L["TEST_TOOLTIP"] or "Test Tooltip", 375, -155)
    
        local testButton = CreateFrame("Button", nil, content, "UIPanelButtonTemplate")
        testButton:SetSize(180, 30)
        testButton:SetPoint("TOPLEFT", content, "TOPLEFT", 350, -170)
        testButton:SetText(L["SHOW_TEST_TOOLTIP"] or "Show Test Tooltip")
    
        local tooltipShown = false
    
        local function UpdateTooltip()
            if self.testTooltipFrame then
                self.testTooltipFrame:Hide()
                self.testTooltipFrame = nil
                self.testTooltip = nil
            end
    
            if not tooltipShown then
                return
            end
    
            local tooltipFrame = CreateFrame("Frame", nil, content)
            tooltipFrame:SetSize(250, 200)
            tooltipFrame:SetPoint("TOPLEFT", testButton, "BOTTOMLEFT", 12.5, -10)

            tooltipFrame:SetBackdropColor(0, 0, 0, 0.8)
            tooltipFrame:SetBackdropBorderColor(0.5, 0.5, 0.5, 1)
    
            local tooltip = CreateFrame("GameTooltip", "MPRTestGameTooltip" .. math.random(1000000), tooltipFrame, "GameTooltipTemplate")
            tooltip:SetOwner(tooltipFrame, "ANCHOR_NONE")
            tooltip:SetPoint("TOPLEFT", tooltipFrame, "TOPLEFT", 0, 0)
    
            self.testTooltipFrame = tooltipFrame
            self.testTooltip = tooltip
    
            if not Addon.TestTooltip then
                tooltip:AddLine("Error: TestTooltip module not available")
                tooltip:Show()
                return
            end
    
            local testPlayerInfo = Addon.TestTooltip:CreateTestPlayerInfo()
            if not testPlayerInfo then
                tooltip:AddLine("Error: Failed to create test player info")
                tooltip:Show()
                return
            end
    
            if Addon.Utils and Addon.Utils.AddMythicPlusInfo then
                Addon.Utils:AddMythicPlusInfo(tooltip, testPlayerInfo, { short = MPR_DB.shortTooltip })
            else
                tooltip:AddLine("Test Player Info")
                tooltip:AddLine("Name: " .. (testPlayerInfo.data.character.name or "Unknown"))
                tooltip:AddLine("Item Level: " .. (testPlayerInfo.data.character.itemLevel or 0))
            end
    
            tooltipFrame:SetHeight(tooltip:GetHeight() + 20)
    
            tooltip:Show()
            tooltipFrame:Show()
        end
    
        SettingsManager.UpdateTestTooltip = UpdateTooltip
    
        testButton:SetScript("OnClick", function()
            tooltipShown = not tooltipShown
    
            if tooltipShown then
                testButton:SetText(L["HIDE_TEST_TOOLTIP"] or "Hide Test Tooltip")
            else
                testButton:SetText(L["SHOW_TEST_TOOLTIP"] or "Show Test Tooltip")
            end
    
            UpdateTooltip()
        end)
    
        self.currentYOffset = self.currentYOffset - 50
    
        return testButton
    end
    

    function SettingsManager:AddHeader(text, x, y)
        local panel = self:CreatePanel()
        local content = panel.content

        self.currentYOffset = self.currentYOffset - 20

        local header = content:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
        if (x ~= nil and y ~= nil) then
            header:SetPoint("TOPLEFT", content, "TOPLEFT", x, y)
        else
            header:SetPoint("TOPLEFT", content, "TOPLEFT", 16, self.currentYOffset)
        end
        header:SetText(text)

        self.currentYOffset = self.currentYOffset - 25

        return header
    end

    function SettingsManager:AddCheckbox(name, description, dbKey, defaultValue)
        local panel = self:CreatePanel()
        local content = panel.content

        local checkbox = CreateFrame("CheckButton", nil, content, "InterfaceOptionsCheckButtonTemplate")
        checkbox:SetPoint("TOPLEFT", content, "TOPLEFT", 16, self.currentYOffset)
        checkbox.Text:SetText(name)

        if MPR_DB[dbKey] == nil and defaultValue ~= nil then
            MPR_DB[dbKey] = defaultValue
        end

        checkbox:SetChecked(MPR_DB[dbKey])

        checkbox:SetScript("OnClick", function(self)
            local isChecked = self:GetChecked()
            MPR_DB[dbKey] = isChecked
            PlaySound(isChecked and 856 or 857)
            Addon:PrintDebug(name .. ": " .. (isChecked and L.ENABLED or L.DISABLED))
            if SettingsManager.testTooltipFrame and SettingsManager.testTooltipFrame:IsShown() then
                SettingsManager.UpdateTestTooltip()
            end
        end)

        if description then
            checkbox:SetScript("OnEnter", function(self)
                GameTooltip:SetOwner(self, "ANCHOR_RIGHT")
                GameTooltip:SetText(name, 1, 1, 1)
                GameTooltip:AddLine(description, nil, nil, nil, true)
                GameTooltip:Show()
            end)

            checkbox:SetScript("OnLeave", function()
                GameTooltip:Hide()
            end)
        end

        self.currentYOffset = self.currentYOffset - 30

        return checkbox
    end

    function SettingsManager:AddSeasonSelector()
        local panel = self:CreatePanel()
        local content = panel.content
    
        local allSeasonsCheckbox = CreateFrame("CheckButton", "MPRAllSeasonsCheckbox", content, "InterfaceOptionsCheckButtonTemplate")
        allSeasonsCheckbox:SetPoint("TOPLEFT", content, "TOPLEFT", 16, self.currentYOffset)
        allSeasonsCheckbox.Text:SetText(L.OPTION_ALL_SEASONS or "Show All Seasons")
    
        local function IsSeasonSelected(seasonNumber)
            if not MPR_DB.showSeasons then
                return true
            end
    
            if MPR_DB.showSeasons._empty then
                return false
            end
    
            if #MPR_DB.showSeasons == 0 then
                return true
            end
    
            for _, season in ipairs(MPR_DB.showSeasons) do
                if season == seasonNumber then
                    return true
                end
            end
    
            return false
        end
    
        local function UpdateSeasonCheckboxes()
            local showAllSeasons = not MPR_DB.showSeasons or (not MPR_DB.showSeasons._empty and #MPR_DB.showSeasons == 0)
    
            allSeasonsCheckbox:SetChecked(showAllSeasons)
    
            for i = 1, _G.MPlusCurrentSeason-1 do
                local seasonCheckbox = _G["MPRSeasonCheckbox" .. i]
                if seasonCheckbox then
                    local isSelected = IsSeasonSelected(i)
                    seasonCheckbox:SetChecked(isSelected)
    
                    seasonCheckbox:SetEnabled(not showAllSeasons)
                    if showAllSeasons then
                        seasonCheckbox:SetAlpha(0.5)
                    else
                        seasonCheckbox:SetAlpha(1.0)
                    end
                end
            end
        end
    
        local seasonCheckboxes = {}
        for i = 1, _G.MPlusCurrentSeason-1 do
            local seasonCheckbox = CreateFrame("CheckButton", "MPRSeasonCheckbox" .. i, content, "InterfaceOptionsCheckButtonTemplate")
            if i <= 3 then
                seasonCheckbox:SetPoint("TOPLEFT", content, "TOPLEFT", 16, self.currentYOffset - i*25)
            end
    
            seasonCheckbox.Text:SetText((L.OPTION_SEASON or "Season") .. " " .. i)
            seasonCheckboxes[i] = seasonCheckbox
    
            seasonCheckbox:SetScript("OnClick", function(self)
                local isChecked = self:GetChecked()
    
                if not MPR_DB.showSeasons or (not MPR_DB.showSeasons._empty and #MPR_DB.showSeasons == 0) then
                    self:SetChecked(true)
                    return
                end
    
                if not MPR_DB.showSeasons then
                    MPR_DB.showSeasons = {}
                end
    
                MPR_DB.showSeasons._empty = nil
    
                if isChecked then
                    local found = false
                    for _, season in ipairs(MPR_DB.showSeasons) do
                        if season == i then
                            found = true
                            break
                        end
                    end
    
                    if not found then
                        table.insert(MPR_DB.showSeasons, i)
                    end
    
                    local allSelected = true
                    for j = 1, _G.MPlusCurrentSeason-1 do
                        local seasonFound = false
                        for _, season in ipairs(MPR_DB.showSeasons) do
                            if season == j then
                                seasonFound = true
                                break
                            end
                        end
    
                        if not seasonFound then
                            allSelected = false
                            break
                        end
                    end
    
                    if allSelected then
                        MPR_DB.showSeasons = {}
                        allSeasonsCheckbox:SetChecked(true)
                    end
                else
                    for j = #MPR_DB.showSeasons, 1, -1 do
                        if MPR_DB.showSeasons[j] == i then
                            table.remove(MPR_DB.showSeasons, j)
                            break
                        end
                    end
    
                    if #MPR_DB.showSeasons == 0 then
                        MPR_DB.showSeasons._empty = true
                    end
                end
    
                PlaySound(isChecked and 856 or 857)
    
                local seasonsText
                if MPR_DB.showSeasons._empty then
                    seasonsText = "No seasons"
                elseif #MPR_DB.showSeasons == 0 then
                    seasonsText = L.ALL_SEASONS or "All seasons"
                else
                    seasonsText = table.concat(MPR_DB.showSeasons, ", ")
                end
                Addon:PrintDebug((L.SEASONS_DISPLAY_CURRENT or "Currently displaying: ") .. seasonsText)
    
                UpdateSeasonCheckboxes()
                if SettingsManager.testTooltipFrame and SettingsManager.testTooltipFrame:IsShown() then
                    SettingsManager.UpdateTestTooltip()
                end
            end)
    
            seasonCheckbox:SetScript("OnEnter", function(self)
                GameTooltip:SetOwner(self, "ANCHOR_RIGHT")
                GameTooltip:SetText((L.OPTION_SEASON or "Season") .. " " .. i, 1, 1, 1)
                GameTooltip:AddLine((L.OPTION_SEASON_DESC or "Display information from Season") .. " " .. i, nil, nil, nil, true)
                GameTooltip:Show()
            end)
    
            seasonCheckbox:SetScript("OnLeave", function()
                GameTooltip:Hide()
            end)
        end
    
        allSeasonsCheckbox:SetScript("OnClick", function(self)
            local isChecked = self:GetChecked()
    
            if isChecked then
                MPR_DB.showSeasons = {}
                Addon:PrintDebug(L.SEASONS_DISPLAY_ALL or "Now displaying all seasons")
            else
                if not MPR_DB.showSeasons then
                    MPR_DB.showSeasons = {}
                else
                    while #MPR_DB.showSeasons > 0 do
                        table.remove(MPR_DB.showSeasons)
                    end
                end
    
                MPR_DB.showSeasons._empty = true
    
                Addon:PrintDebug("No seasons selected. Please select specific seasons.")
            end
    
            PlaySound(isChecked and 856 or 857)
            if SettingsManager.testTooltipFrame and SettingsManager.testTooltipFrame:IsShown() then
                SettingsManager.UpdateTestTooltip()
            end
            UpdateSeasonCheckboxes()
        end)
    
        allSeasonsCheckbox:SetScript("OnEnter", function(self)
            GameTooltip:SetOwner(self, "ANCHOR_RIGHT")
            GameTooltip:SetText(L.OPTION_ALL_SEASONS or "Show All Seasons", 1, 1, 1)
            GameTooltip:AddLine(L.OPTION_ALL_SEASONS_DESC or "Display information from all available seasons", nil, nil, nil, true)
            GameTooltip:Show()
        end)
    
        allSeasonsCheckbox:SetScript("OnLeave", function()
            GameTooltip:Hide()
        end)
    
        UpdateSeasonCheckboxes()
    
        self.currentYOffset = self.currentYOffset - 90
    
        self.UpdateSeasonCheckboxes = UpdateSeasonCheckboxes
        self.IsSeasonSelected = IsSeasonSelected
    
        return {
            allSeasonsCheckbox = allSeasonsCheckbox,
            seasonCheckboxes = seasonCheckboxes,
            updateCheckboxes = UpdateSeasonCheckboxes
        }
    end
    
    return SettingsManager
end

function Addon:InitializeSettings()
    if not self.SettingsManager then
        self.SettingsManager = self:CreateSettingsManager()
        self.SettingsManager:Initialize()
    end
end

function Addon:RegisterCommand(command, handler, help)
    if not command then return end

    command = command:lower()
    self.SlashCommands[command] = {
        handler = handler,
        help = help or ""
    }
end

local frame = CreateFrame("Frame")
frame:RegisterEvent("ADDON_LOADED")
frame:SetScript("OnEvent", function(self, event, arg1)
    if event == "ADDON_LOADED" and arg1 == AddonName then
        Addon:InitializeSettings()
        self:UnregisterEvent("ADDON_LOADED")
    end
end)