local AddonName, Addon = ...

local currentLocale = GetLocale()
local L = Addon.L
local Utils = {}

Utils.DungeonOrder = Addon.DungeonOrder

-- Utils.MPlusColors = {
--     [3725] = "ff8000",
--     [3560] = "fa7736",
--     [3440] = "f46e53",
--     [3320] = "ed656c",
--     [3200] = "e55c84",
--     [3080] = "dc539b",
--     [2960] = "d04ab2",
--     [2840] = "c241c9",
--     [2720] = "b039e0",
--     [2590] = "9246eb",
--     [2470] = "6062e3",
--     [2300] = "1773da",
--     [2180] = "3e81cb",
--     [2060] = "4f8fbc",
--     [1940] = "599dad",
--     [1820] = "5eac9d",
--     [1700] = "5fba8d",
--     [1580] = "5dc97b",
--     [1460] = "57d868",
--     [1340] = "4ce750",
--     [1220] = "37f630",
--     [1100] = "41ff28",
--     [975] = "6fff53",
--     [850] = "8fff73",
--     [725] = "a9ff90"
-- }


function Utils:GetScoreColor(value)
    for _, threshold in ipairs(Addon.SortedThresholds) do
        if value >= threshold then
            return string.format("|cff%s%.0f|r", Addon.MPlusColors[threshold], value)
        end
    end

    return string.format("|cff%s%.0f|r", "ffffff", value)
end

function Utils:GetRoleIcon(role)
    if role == 'TANK' then
        return "|TInterface\\AddOns\\MPlusBfA\\icons\\roles:14:14:0:0:64:64:38:56:0:18|t"
    elseif role == 'HEALER' then
        return "|TInterface\\AddOns\\MPlusBfA\\icons\\roles:14:14:0:0:64:64:19:37:0:18|t"
    elseif role == 'DPS' or role == "DAMAGER" then
        return "|TInterface\\AddOns\\MPlusBfA\\icons\\roles:14:14:0:0:64:64:0:18:0:18|t"
    end
    return L.GENERAL_ROLE
end

function Utils:GetStars(count)
    local STAR_ICON = "|TInterface\\AddOns\\MPlusBfA\\icons\\st:8:8:0:0:0:0:0:0:0:0|t"
    local stars = ""
    for i = 1, count do
        stars = stars .. STAR_ICON
    end
    return stars
end

function Utils:GetPlayerInfo(name)
    if not _G.MPlusAScore_Database or not _G.MPlusAScore_Database[name] then return nil end
    if not _G.MPlusAScore_Database[name].data or not _G.MPlusAScore_Database[name].data.character or not _G.MPlusAScore_Database[name].data.score or not _G.MPlusAScore_Database[name].data.bestRuns then return nil end

    return _G.MPlusAScore_Database[name]
end

function Utils:AddMythicPlusInfo(tooltip, playerInfo, options)
    if not playerInfo or not playerInfo.data or not playerInfo.data.score then return end

    if not options then 
        options = { 
            short = MPR_DB and MPR_DB.shortTooltip or false
        } 
    end

    if not MPR_DB then
        MPR_DB = {}
    end

    if MPR_DB.showSeasons == nil then
        MPR_DB.showSeasons = {}
    end

    if MPR_DB.debug then
        Addon:PrintDebug("showSeasons: " .. (MPR_DB.showSeasons and #MPR_DB.showSeasons > 0 and table.concat(MPR_DB.showSeasons, ", ") or "All"))
    end

    if not options.short and not MPR_DB.hideHeader then
        tooltip:AddLine("Mythic Plus Rating")
        tooltip:AddLine("-----------------------------------")
    end
    local seasonKeys = {}
    for seasonKey, _ in pairs(playerInfo.data.score) do
        if seasonKey ~= "CURRENT_SEASON" then
            local seasonNumber = tonumber(string.match(seasonKey, "SEASON_(%d+)"))
            local shouldDisplay = true

            if MPR_DB.showSeasons._empty then
                shouldDisplay = false
            elseif #MPR_DB.showSeasons > 0 then
                shouldDisplay = false
                for _, allowedSeason in ipairs(MPR_DB.showSeasons) do
                    if seasonNumber == allowedSeason then
                        shouldDisplay = true
                        break
                    end
                end
            end

            if shouldDisplay then
                table.insert(seasonKeys, seasonKey)
            end
        end
    end

    table.sort(seasonKeys, function(a, b)
        local _, _, numAStr = string.find(a, "SEASON_(%d+)")
        local _, _, numBStr = string.find(b, "SEASON_(%d+)")
        local numA = tonumber(numAStr) or 0
        local numB = tonumber(numBStr) or 0
        return numA < numB
    end)

    for _, seasonKey in ipairs(seasonKeys) do
        local seasonData = playerInfo.data.score[seasonKey]
        if seasonData then
            for _, scoreData in pairs(seasonData) do
                if scoreData.type == "OVERALL" then
                    local seasonName = L["SEASON_" .. string.match(seasonKey, "SEASON_(%d+)")] or seasonKey
                    local scoreText = string.format("%s: %s (%s: %d)",
                        seasonName,
                        self:GetScoreColor(scoreData.score),
                        L.RANK,
                        scoreData.rank)
                    if MPR_DB.hideRank then
                        scoreText = string.format("%s: %s",
                        seasonName,
                        self:GetScoreColor(scoreData.score))
                    end
                    tooltip:AddLine(scoreText)
                    break
                end
            end
        end
    end

    if playerInfo.data.score.CURRENT_SEASON then
        for _, scoreData in pairs(playerInfo.data.score.CURRENT_SEASON) do
            if scoreData.type == "OVERALL" then

                local scoreText = string.format("M+ Score: %s (%s: %d) [iLvl: %d]",
                self:GetScoreColor(scoreData.score),
                L.RANK,
                scoreData.rank,
                playerInfo.data.character.itemLevel)

                if MPR_DB.hideRank then
                    scoreText = string.format("M+ Score: %s [iLvl: %d]",
                    self:GetScoreColor(scoreData.score),
                    playerInfo.data.character.itemLevel)
                end
                if MPR_DB.hideILvl then
                    scoreText = string.format("M+ Score: %s (%s: %d)",
                    self:GetScoreColor(scoreData.score),
                    L.RANK,
                    scoreData.rank)
                end

                if MPR_DB.hideILvl and MPR_DB.hideRank then
                    scoreText = string.format("M+ Score: %s",
                    self:GetScoreColor(scoreData.score))
                end

                
                tooltip:AddLine(scoreText)
                break
            end
        end
    end

    if not options.short then
        if playerInfo.data.score.CURRENT_SEASON then
            for i, scoreData in pairs(playerInfo.data.score.CURRENT_SEASON) do
                if scoreData.type ~= "OVERALL" and MPR_DB.hideRoles ~= true then
                    local scoreText = string.format("%s Score: %s",
                        self:GetRoleIcon(scoreData.type),
                        self:GetScoreColor(scoreData.score))
                    tooltip:AddLine(scoreText)
                end
            end
        end 
    end


    if not options.short then
        self:AddDungeonInfo(tooltip, playerInfo.data.bestRuns, false)
    else
        self:AddDungeonInfo(tooltip, playerInfo.data.bestRuns, true)
    end
end

function Utils:AddMySuccesses(tooltip, runs) 

end

function Utils:AddLFGMembers(tooltip, members)
    tooltip:AddLine(L.CREW)
    for _, member in pairs(members) do
        local member = string.format("%s|cff%s%s|r",
            self:GetRoleIcon(member.role),
            L.ROLES_COLOR[member.class],
            member.class)
        tooltip:AddLine(member)
    end
end

function Utils:ClearLines(tooltip)
    tooltip:ClearLines()
end

function Utils:AddDungeonInfo(tooltip, bestRuns, short)
    if not bestRuns then return end

    local bestRunsCount = 0
    for _, _ in pairs(bestRuns) do
        bestRunsCount = bestRunsCount + 1
    end

    if bestRunsCount == 0 then return end;


    if not short and MPR_DB.enableTop1 ~= true then
        tooltip:AddLine(string.format("|cFFFFFF00%s|r", L.BEST_KEYS))
    end
    local sortedRuns = {}
    local maxLevels = {}

    for i, run in pairs(bestRuns) do
        if run and run.run and run.run.dungeon and run.run.dungeon.displayName and run.run.dungeon.displayName.ru then
            table.insert(sortedRuns, run)
        else
            print(L.BEST_RUNS_ERROR)
        end
    end

    if not short then
        table.sort(sortedRuns, function(a, b)
            local orderA = self.DungeonOrder[a.run.dungeon.displayName.ru] or 999
            local orderB = self.DungeonOrder[b.run.dungeon.displayName.ru] or 999
            if orderA == orderB then
                return a.run.level > b.run.level
            end
            return orderA < orderB
        end)
    else
        table.sort(sortedRuns, function(a, b)
            local levelA = a.run.level or 0
            local starsA = a.run.numChests or 0
            local levelB = b.run.level or 0
            local starsB = b.run.numChests or 0
            
            if (starsA > 0) ~= (starsB > 0) then
                return starsA > starsB
            end
            
            if levelA ~= levelB then
                return levelA > levelB
            end
            
            return starsA > starsB
        end)
        
    end

    for _, run in ipairs(sortedRuns) do
        local dungeon = run.run.dungeon.displayName.ru
        local level = run.run.level
        local inTime = run.run.numChests > 0
        local stars = inTime and self:GetStars(run.run.numChests) or ""
        
        local text
        if inTime then
            text = string.format("%d |cFFffffff%s|r %s", level, L.DUNGEONS[dungeon], stars)
        else
            text = string.format("%d |cFFb5b1b1%s|r", level, L.DUNGEONS[dungeon])
        end

        if short or MPR_DB.enableTop1 then
            tooltip:AddLine(L.MAX_KEY .. text)
            break
        else
            tooltip:AddLine(text)
        end
    end
end

Addon.Utils = Utils
return Utils