local AddonName, Addon = ...

Addon.Modules = {}
Addon.SlashCommands = {}
L = Addon.L

function Addon:CreateModule(name)
    if self.Modules[name] then
        error(string.format("Module '%s' already exists!", name))
        return
    end

    local module = {
        name = name,
        events = {},
        commands = {}
    }

    function module:RegisterEvent(event, handler)
        if not self.eventFrame then
            self.eventFrame = CreateFrame("Frame")
            self.eventFrame:SetScript("OnEvent", function(_, event, ...)
                if self.events[event] then
                    self.events[event](...)
                end
            end)
        end
        
        self.events[event] = handler
        self.eventFrame:RegisterEvent(event)
    end

    function module:UnregisterEvent(event)
        if self.eventFrame and self.events[event] then
            self.events[event] = nil
            self.eventFrame:UnregisterEvent(event)
        end
    end

    function module:RegisterCommand(command, handler, help)
        if not command then return end
        
        command = command:lower()
        self.commands[command] = {
            handler = handler,
            help = help or ""
        }
        
        Addon.SlashCommands[command] = {
            module = self,
            handler = handler,
            help = help or ""
        }
    end

    self.Modules[name] = module
    return module
end

function Addon:GetModule(name)
    return self.Modules[name]
end

function Addon:HandleSlashCommand(msg)
    local command, rest = msg:match("^(%S*)%s*(.-)$")
    command = command:lower()

    if command == "" then
        self:PrintHelp()
        return
    end

    if command == "debug" then
        MPR_DB.debug = not MPR_DB.debug
        self:Print(L.DEBUG_MODE .. (MPR_DB.debug and L.ENABLED2 or L.DISABLED2))
        return
    end

    local cmdInfo = self.SlashCommands[command]
    if cmdInfo and cmdInfo.handler then
        cmdInfo.handler(rest)
    else
        self:Print(L.UNKNOW_COMMAND)
    end
end

function Addon:PrintHelp()
    self:Print(L.AVAILABLE_COMMANDS)
    self:Print("/mpr debug - " .. L.DEBUG_MODE_TOOGLE_DESK)
    
    for cmd, info in pairs(self.SlashCommands) do
        if info.help then
            self:Print("/mpr " .. cmd .. " - " .. info.help)
        end
    end
end

function Addon:PrintDebug(msg)
    if MPR_DB and MPR_DB.debug then
        print("[|cFF00FF00MPR-Debug:|r] " .. tostring(msg))
    end
end

function Addon:Print(msg)
    print("[|cFF00FF00MPR|r] " .. tostring(msg))
end

SLASH_MPR1 = "/mpr"
SlashCmdList["MPR"] = function(msg)
    Addon:HandleSlashCommand(msg)
end

return Addon
