local AddonName, Addon = ...

local function InitializeDB()
    if not MPR_DB then
        MPR_DB = {
            enabled = true,
            debug = false,
            version = "1.0"
        }
    end
end

local function InitializeModules()
    for name, module in pairs(Addon.Modules) do
        if type(module.Initialize) == "function" then
            local success, error = pcall(module.Initialize, module)
            if not success then
                Addon:PrintDebug(L.MODULE_INIT_ERROR .. name .. ": " .. tostring(error))
            else
                Addon:PrintDebug(L.MODULE_INIT_SUCCES .. name)
            end
        end
    end
end

local function Initialize()
    InitializeDB()
    InitializeModules()
end

local eventFrame = CreateFrame("Frame")

eventFrame:RegisterEvent("ADDON_LOADED")
eventFrame:RegisterEvent("PLAYER_LOGIN")

eventFrame:SetScript("OnEvent", function(self, event, ...)
    if event == "ADDON_LOADED" then
        local addOnName = ...
        if addOnName == AddonName then
            Addon:PrintDebug("Аддон загружается...")
            Initialize()
        end
    elseif event == "PLAYER_LOGIN" then
        local webSite = GetAddOnMetadata("MPlusBfA", "X-Website")
        Addon:Print(string.format(L.UPDATE_MESSAGE,webSite))
        C_Timer.After(1, function()
            if not _G.MPlusAScore_Database then
                Addon:Print(string.format(L.DATABASE_NOT_FOUND, webSite))
            else 
                local currentVersion = GetAddOnMetadata("MPlusBfA", "Version");
                local lastUpdateVersion = _G.MPlusLastVersion;
                Addon:PrintDebug(string.format(L.DEBUG_VERSIONS_CHECK, lastUpdateVersion, currentVersion))
                if lastUpdateVersion ~= currentVersion then
                    Addon:Print(string.format(L.NEW_VERSION_AVAILABLE, lastUpdateVersion, webSite))
                end
            end
        end)
    end
end)